@@ -901,4 +901,17 @@ subtractOffset <- function(new_x, offset){
     new_x[,i] <- new_x[,i] - offset[1,i]
   }
   return(new_x)
-}
\ No newline at end of file
+}
+
+
+# This function throws an error if a user tries to include "cluster(x)" 
+# on the right hand side of a formula
+checkFor_cluster = function(form){
+  # Extracting right hand side
+  rhs = form[[3]]
+  # Turning into characters
+  rhs_char = as.character(rhs)
+  
+  if(any(grepl("cluster\\(", rhs_char) ) ) 
+    stop("cluster(covar) not implemented in icenReg. To account for repeated measures, see ?ir_clustBoot")
+}
